# Dash Addons

## What is it?

An addictional toolbox for Ployly Dash.

## Main Features

- **img_converter** for showing img on dash.

## Where to get it

Example-Package can be installed from PyPI using `pip`:

```bash
pip install dash-addons
```

## Interface

TBA.
